Assignment class

Assignment statement: variable = value or variable += value

Inheritance

Constructors

Assignment(String variable, AssignmentOperator operator, List<Value> values, [SourceSpan? span])
Assignment.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
operator AssignmentOperator
final
parent ConfigElement?
Parent element in the AST (null if at top level). This is NOT populated by the parser by default; use buildBlockHierarchy() to establish links for Block and Command nodes.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span ↔ SourceSpan?
Source span for this element (optional for backwards compatibility)
getter/setter pairinherited
trailingComment String?
Inline comment at the end of the line (without # prefix).
getter/setter pair
values List<Value>
final
variable String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSpan(SourceSpan span) → void
Set the source span for this element
inherited
toJson() Map<String, dynamic>
Convert to JSON representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited