BlockHandler class abstract

Handler for specific block types.

Implementers

Constructors

BlockHandler()

Properties

blockType String
Get the block type this handler processes.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(Block block, Context context) FutureOr<void>
Handle a block with the given context. Can return a Future for async operations or void for sync operations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processChildren(Block block, Context context) FutureOr<void>?
Process child elements of the block.
registerScopedCommands(BlockHandlerRegistry registry) → void
Register block-scoped command handlers for this block type. Override this method to register commands that should only be active within this block type.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited