Command class

Generic command statement

Inheritance
Available extensions

Constructors

Command(String head, List<Value> args, [List<Criterion>? criteria, Block? block, SourceSpan? span])
Command.fromJson(Map<String, dynamic> json)
factory

Properties

args List<Value>
final
block Block?
final
criteria List<Criterion>?
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span ↔ SourceSpan?
Source span for this element (optional for backwards compatibility)
getter/setter pairinherited
trailingComment String?
Inline comment at the end of the line (without # prefix).
getter/setter pair

Methods

getAllArgsAsStrings(Context context) List<String>

Available on Command, provided by the CommandValueExtraction extension

Get all arguments as strings with variable expansion.
getArgAsBool(int index, Context context) bool

Available on Command, provided by the CommandValueExtraction extension

Get argument as boolean with variable expansion.
getArgAsDouble(int index, Context context) double

Available on Command, provided by the CommandValueExtraction extension

Get argument as double with variable expansion.
getArgAsInt(int index, Context context) int

Available on Command, provided by the CommandValueExtraction extension

Get argument as integer with variable expansion.
getArgAsString(int index, Context context) String

Available on Command, provided by the CommandValueExtraction extension

Get argument as string with variable expansion.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSpan(SourceSpan span) → void
Set the source span for this element
inherited
toJson() Map<String, dynamic>
Convert to JSON representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited