ConfigFormatter class

Formats an i3 config AST back to formatted config text.

Constructors

ConfigFormatter({FormatterOptions? options})

Properties

hashCode int
The hash code for this object.
no setterinherited
options FormatterOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(Config config) String
Formats config and returns the formatted config text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited