ConfigVisitor<T> class
abstract
Base visitor interface for processing configuration elements.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitArrayValue(
ArrayValue value) → T - Visit an ArrayValue element.
-
visitAssignment(
Assignment assignment) → T - Visit an Assignment element.
-
visitBlock(
Block block) → T - Visit a Block element.
-
visitCommand(
Command command) → T - Visit a Command element.
-
visitComment(
Comment comment) → T - Visit a Comment element.
-
visitConfig(
Config config) → T - Visit a Config element (root container).
-
visitValue(
Value value) → T - Visit a Value element.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited