FormatterOptions class

Options for configuring the ConfigFormatter.

Constructors

FormatterOptions({int indent = 2, bool sortAssignments = false, bool trailingNewline = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
indent int
Number of spaces per indentation level.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortAssignments bool
Whether to sort assignments alphabetically within their parent context.
final
trailingNewline bool
Whether to add a trailing newline at the end of the output.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited