InterpolatedString class

Double-quoted string with variable interpolation, e.g. "base/$dir/config".

Inheritance

Constructors

InterpolatedString(List<ValueSegment> segments, String quoteChar, [SourceSpan? span])
InterpolatedString.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
quoteChar String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<ValueSegment>
final
span ↔ SourceSpan?
Source span for this value (optional for backwards compatibility)
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSpan(SourceSpan span) → void
Set the source span for this value
inherited
toConfigString() String
Format this value as it would appear in an i3 config file.
override
toJson() Map<String, dynamic>
Convert to JSON representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited