ManualProcessing extension

Extension to provide manual element processing for custom block handlers.

on

Methods

processElements(List<ConfigElement> elements) Future<void>

Available on ConfigProcessor, provided by the ManualProcessing extension

Manually process a list of elements. This is useful for block handlers that set processChildrenAutomatically = false and want to process children with custom logic (filtering, reordering, multi-pass, etc.).