PhysicalFileSystem class

Default FileSystem implementation backed by dart:io.

Implemented types

Constructors

PhysicalFileSystem()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(String path) Future<String?>
Read the content of path. Returns null if the file does not exist.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited