ProcessorState class abstract

Base state for the configuration processor.

Implementers

Constructors

ProcessorState()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateName String
Get the current state name for debugging.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(ConfigElement element, ConfigProcessor processor) FutureOr<void>
Process a configuration element in this state. Can be async if handlers perform async operations.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited