ArrayValue class
Array value: ["a", "b", "c"]
Constructors
-
ArrayValue(List<
Value> items, [SourceSpan? span]) -
ArrayValue.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSpan(
SourceSpan span) → void -
Set the source span for this value
inherited
-
toConfigString(
) → String -
Format this value as it would appear in an i3 config file.
override
-
toJson(
) → Map< String, dynamic> -
Convert to JSON representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited