DefaultChildProcessing mixin
Provides default automatic child processing. Mix this in for standard sequential processing (most common case).
Returning null signals the processor to use default automatic processing.
If you override with an async method, the returned Future signals
custom processing — use afterChildrenProcessed instead if you need
async post-processing while keeping default child processing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processChildren(
Block block, Context context) → FutureOr< void> ? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited